==> haskell-success-0.2.6-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-KHuOdSzga3lKHiIsiVUDEz
key: success-0.2.6-KHuOdSzga3lKHiIsiVUDEz
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: b92fbcb78a1f47d3d3d8a4f696511b26
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/success-0.2.6
hs-libraries: HSsuccess-0.2.6-KHuOdSzga3lKHiIsiVUDEz
depends:
    transformers-base-0.4.5.2-5lZG7zcu5n88PiL2AgOVTn
    monad-control-1.0.2.3-3MYTwgYPDl9DXJG66ALzdg mtl-2.2.2
    transformers-0.5.5.0 base-4.11.1.0
abi-depends: transformers-base-0.4.5.2-5lZG7zcu5n88PiL2AgOVTn=717b04fa9c4ac9f0c16847f16e279a2e
             monad-control-1.0.2.3-3MYTwgYPDl9DXJG66ALzdg=fd3e07cd2d2294fc0b5df1a3560bc8f9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-26-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: success
version: 0.2.6
id: success-0.2.6-CznFUPuYvM75qncUuqKLwQ
key: success-0.2.6-CznFUPuYvM75qncUuqKLwQ
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/success
synopsis: A version of Either specialised for encoding of success or failure
description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.
category: Data, Failure
abi: 59b68e5141805359def2a5f2c181c17d
exposed: True
exposed-modules:
    Success.Impure Success.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/success-0.2.6
hs-libraries: HSsuccess-0.2.6-CznFUPuYvM75qncUuqKLwQ
depends:
    transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb
    monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk mtl-2.2.2
    transformers-0.5.5.0 base-4.11.1.0
abi-depends: transformers-base-0.4.5.2-5YBw5fGTiDqHDjkVkrHRIb=b60c703c8501b255d99b1477d141017d
             monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk=7b91fe2931b6520a589ebb0da769a2de
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-success/html/success.haddock
haddock-html: /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
